@@ -2,5 +2,5 @@ __all__ = [
     "cls_item",
     "constants",
     "helper_files",
-    "parser"
+    "parser",
 ]
