@@ -75,8 +75,29 @@ class Stash():
         self.__list += res
         return res
 
+    def Append(self, item):
+        """appends one or mote items to the stash
+
+        Args:
+            item (Item): Item(s) to append
+        """
+        if isinstance(item, (list, tuple)):
+            for _item in item:
+                self.__list.append(_item)
+        else:
+            self.__list.append(item)
+
     def Remove(self, item):
-        self.__list.remove(item)
+        """removes one or more items from the stash
+
+        Args:
+            item (Item): Item(s) to remove
+        """
+        if isinstance(item, (list, tuple)):
+            for _item in item:
+                self.__list.remove(_item)
+        else:
+            self.__list.remove(item)
 
     def AddDistroMachineFromLayer(self, path):
         _root = get_layer_root(path)
